# Debugging level, 0=errors only, 1=return status of smtp server,
#   2=smtp server communication, 3=detailed smtp server communication,
#   4=smtp client communication
DEBUG_LEVEL=3

# Where is new root path. For example '/var/spool/vscan'
CHROOT='/home/ondrejj/sh/sagator/root'

# User and group, under which this program runs.
USER='vscan'
GROUP='vscan'

# Buffer size for some of operations.
BUFSIZE=10240

# SMTP server host and port. You must define this smtp server
# in postfix without filtering.
SMTP_HOST='127.0.0.1'
SMTP_PORT=26

# Quarantine dir, in which are stored viruses and spams.
QUARANTINE_DIR='/tmp/quarantine'

# Scanners
from base import *
from mimeparse import mimeparse,mime_ext
from clamav import clamscan,clamd
from nodold import nodold
from spamassassin import spamassassin,spamassassind

# Define scanners
SPAMSTRING='^X-Spam-Level: \*\*\*\*\*'
SA_MAX_FILE=500000
EXECUTABLES='(\.exe|\.com|\.pif|\.lnk|\.scr|\.vbs)$'
SCANNERS=[
  # ClamAV
  #clamscan(['/usr/bin/clamscan','--stdout','--infected','--disable-summary','-r','--mbox']),
  #mimeparse(stream2file(clamscan(['/usr/bin/clamscan','--stdout','--infected','--disable-summary','-r']))),
  clamd(['localhost',3310]),
  #clamd('/var/spool/vscan/clamd'),
  #mimeparse(clamd(['localhost',3310])),
  # Simple scanners
  #string_scan({'virname':'___PATTERN___'}),
  #regexp_scan({'virname':'___PATTERN___'}),
  # Mime Extentsion
  mime_ext(EXECUTABLES),
  # NODOLD
  #mimeparse(stream2file(nodold(['localhost',8448]))),
  # SpamAssassin
  spamassassind(['localhost',783],SPAMSTRING,SA_MAX_FILE),
  #spamassassin(['/usr/bin/spamassassin','-e'],SPAMSTRING,SA_MAX_FILE),
  finalscanner()
]
TEMPFAIL_ON_SCANNER_FAIL=1

# Drop emails, which contains viruses or spams.
# Define a regular expression pattern. If this pattern is found
# in reply of scanner, then mail is dropped elsewhere, it is rejected.
DROP='(SPAM|sobig|frethem|lirva|klez|palyh|bugbear)'

# Send virus reports as ...
REPORT_SENDER="viralert@salstar.sk"
# Send virus reports to ["...","..."]
REPORT_RECIPIENTS=["vir@salstar.sk"]

# MESSAGE SENT AS REPORT
REPORT_MSG='''From: %s
To: %s
Subject: ALERT, %s FOUND!

                             VIRUS FOUND!

---------------------------------------------------------------------
MAIL FROM: %s
RCPT TO: %s
STATUS: %s
QUARANTINED AS: %s
---------------------------------------------------------------------
OUTPUT OF SCANNER:
%s\
---------------------------------------------------------------------
HEADER OF MESSAGE:
%s\
'''
